@@ -1,4 +1,4 @@
-"""dump command for osxphotos CLI """
+"""dump command for osxphotos CLI"""
 
 import click
 
@@ -8,6 +8,7 @@ from osxphotos.cli.click_rich_echo import (
     set_rich_console,
     set_rich_theme,
 )
+from osxphotos.cli.template_utils import suggest_template_fields
 from osxphotos.iphoto import is_iphoto_library
 from osxphotos.photoquery import QueryOptions
 from osxphotos.phototemplate import RenderOptions
@@ -58,7 +59,7 @@ def dump(
     """Print list of all photos & associated info from the Photos library.
 
     NOTE: dump is DEPRECATED and will be removed in a future release.
-    Use `osxphotos query` instead.
+    Use 'osxphotos query' instead.
     """
 
     # below needed for to make CliRunner work for testing
@@ -112,9 +113,11 @@ def dump(
                     options,
                 )
                 if unmatched:
-                    rich_click_echo(
-                        f"[warning]Unmatched template field: {unmatched}[/]"
-                    )
+                    suggested = suggest_template_fields(unmatched)
+                    error_str = f"[warning]Unmatched template field: {unmatched}"
+                    if suggested:
+                        error_str += f"; did you mean {suggested}?"
+                    rich_click_echo(error_str)
                 for rendered_template in rendered_templates:
                     if not rendered_template:
                         continue
