@@ -660,7 +660,12 @@ def set_photo_property(photo: photoscript.Photo, property: str, value: Any):
     if property == "keywords" and not isinstance(value, list):
         raise ValueError(f"keywords must be a list, not {type(value)}")
     elif property in {"title", "description"} and not isinstance(value, str):
-        raise ValueError(f"{property} must be a str, not {type(value)}")
+        # If the value is missing or is not a string, setting it to an empty string, will result in an error.
+        # So we can ignore this property if the value is None or not a string.
+        echo_error(
+            f"[warning] The property '{property}' of '{photo.original_filename}' is missing or invalid."
+        )
+        return
     elif property == "favorite":
         value = bool(value)
     elif property == "location":
