@@ -672,6 +672,20 @@ class PhotoInfo:
             else None
         )
 
+    @cached_property
+    def imported_by(self) -> tuple[str | None, str | None]:
+        """Returns tuple of 'imported by' display name and bundle ID; one or both may be None; Photos 7+ only, on earlier versions returns (None, None)
+
+        For example: ('Photos', 'com.apple.Photos'); ('Camera', 'com.apple.camera'); ('Messages', 'com.apple.MobileSMS')
+        """
+        if self._db._db_version <= _PHOTOS_4_VERSION:
+            return None, None
+
+        return (
+            self._info["imported_by_display_name"],
+            self._info["imported_by_bundle_id"],
+        )
+
     @property
     def project_info(self) -> list[ProjectInfo]:
         """list of ProjectInfo objects representing projects for the photo or None if no projects"""
@@ -741,6 +755,24 @@ class PhotoInfo:
             return None
         return plist_file
 
+    @property
+    def original_adjustments_path(self) -> pathlib.Path | None:
+        """Returns path to original adjustments file or None if file doesn't exist (for example, Portrait images contain an origial adjustments file)"""
+        if self._db._db_version <= _PHOTOS_4_VERSION:
+            return None
+
+        library = self._db._library_path
+        directory = self._uuid[0]  # first char of uuid
+        aae_file = (
+            pathlib.Path(library)
+            / "originals"
+            / directory
+            / f"{self._uuid}_5.aae"  # There may be other AAE files but the _5 variant is all I've seen
+        )
+        if not aae_file.is_file():
+            return None
+        return aae_file
+
     @property
     def adjustments(self) -> AdjustmentsInfo | None:
         """Returns AdjustmentsInfo class for adjustment data or None if no adjustments; Photos 5+ only"""
@@ -753,6 +785,13 @@ class PhotoInfo:
             self._adjustmentinfo = AdjustmentsInfo(plist_file)
             return self._adjustmentinfo
 
+    @cached_property
+    def original_adjustments(self) -> AdjustmentsInfo | None:
+        """Returns AdjustmentsInfo class for original adjustment data or None if no adjustments; Photos 5+ only"""
+        if self.original_adjustments_path:
+            return AdjustmentsInfo(self.original_adjustments_path)
+        return None
+
     @property
     def adjustment_type(self) -> int | None:
         """Returns adjustment type as int or None if no adjustments"""
@@ -962,6 +1001,18 @@ class PhotoInfo:
         )
         return bool(burst_pick_type & BURST_KEY)
 
+    @property
+    def burst_key_photo(self) -> PhotoInfo | None:
+        """If a photo is part of a burst group, returns the PhotoInfo object for the key photo of a burst group otherwise None"""
+        if not self.burst:
+            return None
+        if self.burst_key:
+            return self
+        for photo in self.burst_photos:
+            if photo.burst_key:
+                return photo
+        return None
+
     @property
     def burst_default_pick(self) -> bool:
         """Returns True if photo is a burst image and is the photo that Photos selected as the default image for the burst set, otherwise False"""
@@ -1280,7 +1331,7 @@ class PhotoInfo:
                     except Exception as e:
                         # sometimes the reverse geolocation data is corrupted
                         # and this can cause a UnsupportedArchiver error
-                        logging.warning(
+                        logger.warning(
                             f"Error creating PlaceInfo5 for {self.uuid}: {str(e)}"
                         )
                         self._place = None
@@ -1363,7 +1414,7 @@ class PhotoInfo:
                     duplicates.append(self._db.get_photo(uuid))
         except KeyError:
             # don't expect this to happen as the signature should be in db
-            logging.warning(f"Did not find signature for {self.uuid} in _db_signatures")
+            logger.warning(f"Did not find signature for {self.uuid} in _db_signatures")
         return duplicates
 
     @property
@@ -1651,7 +1702,7 @@ class PhotoInfo:
             except FileNotFoundError:
                 # get_exiftool_path raises FileNotFoundError if exiftool not found
                 exiftool = None
-                logging.warning(
+                logger.warning(
                     "exiftool not in path; download and install from https://exiftool.org/"
                 )
 
@@ -1734,7 +1785,7 @@ class PhotoInfo:
             try:
                 detected_text = self._detected_text()
             except Exception as e:
-                logging.warning(f"Error detecting text in photo {self.uuid}: {e}")
+                logger.warning(f"Error detecting text in photo {self.uuid}: {e}")
                 detected_text = []
 
             self._detected_text_cache[confidence_threshold] = [
@@ -2166,6 +2217,10 @@ class PhotoInfo:
             dict_data["tzname"] = self.tzname
             dict_data["media_analysis"] = self.media_analysis
             dict_data["ai_caption"] = self.ai_caption
+            dict_data["original_adjustments"] = (
+                self.original_adjustments.asdict() if self.original_adjustments else {}
+            )
+            dict_data["imported_by"] = self.imported_by
 
         return dict_data
 
@@ -2307,7 +2362,7 @@ def frozen_photoinfo_factory(photo: PhotoInfo) -> SimpleNamespace:
             try:
                 detected_text = frozen._detected_text()
             except Exception as e:
-                logging.warning(f"Error detecting text in photo {frozen.uuid}: {e}")
+                logger.warning(f"Error detecting text in photo {frozen.uuid}: {e}")
                 detected_text = []
 
             frozen._detected_text_cache[confidence_threshold] = [
